<?php

namespace Litecms\Usernotice\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Usernotice\Models\Usernotice;

class UsernoticePolicy
{

    /**
     * Determine if the given user can view the usernotice.
     *
     * @param UserPolicy $user
     * @param Usernotice $usernotice
     *
     * @return bool
     */
    public function view(UserPolicy $user, Usernotice $usernotice)
    {
        if ($user->canDo('usernotice.usernotice.view') && $user->isAdmin()) {
            return true;
        }

        return $usernotice->user_id == user_id() && $usernotice->user_type == user_type();
    }

    /**
     * Determine if the given user can create a usernotice.
     *
     * @param UserPolicy $user
     * @param Usernotice $usernotice
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('usernotice.usernotice.create');
    }

    /**
     * Determine if the given user can update the given usernotice.
     *
     * @param UserPolicy $user
     * @param Usernotice $usernotice
     *
     * @return bool
     */
    public function update(UserPolicy $user, Usernotice $usernotice)
    {
        if ($user->canDo('usernotice.usernotice.edit') && $user->isAdmin()) {
            return true;
        }

        return $usernotice->user_id == user_id() && $usernotice->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given usernotice.
     *
     * @param UserPolicy $user
     * @param Usernotice $usernotice
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Usernotice $usernotice)
    {
        return $usernotice->user_id == user_id() && $usernotice->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given usernotice.
     *
     * @param UserPolicy $user
     * @param Usernotice $usernotice
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Usernotice $usernotice)
    {
        if ($user->canDo('usernotice.usernotice.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given usernotice.
     *
     * @param UserPolicy $user
     * @param Usernotice $usernotice
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Usernotice $usernotice)
    {
        if ($user->canDo('usernotice.usernotice.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
